@@ -18,7 +18,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
+#include "config.h"
 #include <cairo-ft.h>
 
 #include "pangofc-fontmap.h"
@@ -52,15 +52,10 @@ pango_cairo_fc_font_map_get_resolution_cairo (PangoCairoFontMap *cfontmap)
   return cffontmap->dpi;
 }
 
-static PangoRenderer *
-pango_cairo_fc_font_map_get_renderer (PangoCairoFontMap *cfontmap)
+static cairo_font_type_t
+pango_cairo_fc_font_map_get_font_type (PangoCairoFontMap *cfontmap G_GNUC_UNUSED)
 {
-  PangoCairoFcFontMap *cffontmap = (PangoCairoFcFontMap *) (cfontmap);
-
-  if (!cffontmap->renderer)
-    cffontmap->renderer = g_object_new (PANGO_TYPE_CAIRO_RENDERER, NULL);
-
-  return cffontmap->renderer;
+  return CAIRO_FONT_TYPE_FT;
 }
 
 static void
@@ -68,7 +63,7 @@ cairo_font_map_iface_init (PangoCairoFontMapIface *iface)
 {
   iface->set_resolution = pango_cairo_fc_font_map_set_resolution;
   iface->get_resolution = pango_cairo_fc_font_map_get_resolution_cairo;
-  iface->get_renderer = pango_cairo_fc_font_map_get_renderer;
+  iface->get_font_type  = pango_cairo_fc_font_map_get_font_type;
 }
 
 G_DEFINE_TYPE_WITH_CODE (PangoCairoFcFontMap, pango_cairo_fc_font_map, PANGO_TYPE_FC_FONT_MAP,
@@ -79,23 +74,20 @@ pango_cairo_fc_font_map_finalize (GObject *object)
 {
   PangoCairoFcFontMap *cffontmap = (PangoCairoFcFontMap *) (object);
 
-  if (cffontmap->renderer)
-    g_object_unref (cffontmap->renderer);
+  G_OBJECT_CLASS (pango_cairo_fc_font_map_parent_class)->finalize (object);
 
   FT_Done_FreeType (cffontmap->library);
-
-  G_OBJECT_CLASS (pango_cairo_fc_font_map_parent_class)->finalize (object);
 }
 
 static void
-pango_cairo_fc_font_map_context_substitute (PangoFcFontMap *fcfontmap,
-					    PangoContext   *context,
-					    FcPattern      *pattern)
+pango_cairo_fc_font_map_fontset_key_substitute (PangoFcFontMap    *fcfontmap G_GNUC_UNUSED,
+						PangoFcFontsetKey *fontkey,
+						FcPattern         *pattern)
 {
   FcConfigSubstitute (NULL, pattern, FcMatchPattern);
 
-  if (context)
-    cairo_ft_font_options_substitute (_pango_cairo_context_get_merged_font_options (context),
+  if (fontkey)
+    cairo_ft_font_options_substitute (pango_fc_fontset_key_get_context_key (fontkey),
 				      pattern);
 
   FcDefaultSubstitute (pattern);
@@ -122,21 +114,21 @@ pango_cairo_fc_font_map_get_resolution_fc (PangoFcFontMap *fcfontmap,
 }
 
 static gconstpointer
-pango_cairo_fc_font_map_context_key_get (PangoFcFontMap *fcfontmap,
+pango_cairo_fc_font_map_context_key_get (PangoFcFontMap *fcfontmap G_GNUC_UNUSED,
 					 PangoContext   *context)
 {
   return _pango_cairo_context_get_merged_font_options (context);
 }
 
 static gpointer
-pango_cairo_fc_font_map_context_key_copy (PangoFcFontMap *fcfontmap,
+pango_cairo_fc_font_map_context_key_copy (PangoFcFontMap *fcfontmap G_GNUC_UNUSED,
 					  gconstpointer   key)
 {
   return cairo_font_options_copy (key);
 }
 
 static void
-pango_cairo_fc_font_map_context_key_free (PangoFcFontMap *fcfontmap,
+pango_cairo_fc_font_map_context_key_free (PangoFcFontMap *fcfontmap G_GNUC_UNUSED,
 					  gpointer        key)
 {
   cairo_font_options_destroy (key);
@@ -144,14 +136,14 @@ pango_cairo_fc_font_map_context_key_free (PangoFcFontMap *fcfontmap,
 
 
 static guint32
-pango_cairo_fc_font_map_context_key_hash (PangoFcFontMap *fcfontmap,
+pango_cairo_fc_font_map_context_key_hash (PangoFcFontMap *fcfontmap G_GNUC_UNUSED,
 					  gconstpointer        key)
 {
   return (guint32)cairo_font_options_hash (key);
 }
 
 static gboolean
-pango_cairo_fc_font_map_context_key_equal (PangoFcFontMap *fcfontmap,
+pango_cairo_fc_font_map_context_key_equal (PangoFcFontMap *fcfontmap G_GNUC_UNUSED,
 					   gconstpointer   key_a,
 					   gconstpointer   key_b)
 {
@@ -159,13 +151,11 @@ pango_cairo_fc_font_map_context_key_equal (PangoFcFontMap *fcfontmap,
 }
 
 static PangoFcFont *
-pango_cairo_fc_font_map_create_font (PangoFcFontMap             *fcfontmap,
-				     PangoContext               *context,
-				     const PangoFontDescription *desc,
-				     FcPattern                  *pattern)
+pango_cairo_fc_font_map_create_font (PangoFcFontMap *fcfontmap,
+				     PangoFcFontKey *key)
 {
   return _pango_cairo_fc_font_new ((PangoCairoFcFontMap *) (fcfontmap),
-				   context, desc, pattern);
+				   key);
 }
 
 static void
@@ -176,7 +166,7 @@ pango_cairo_fc_font_map_class_init (PangoCairoFcFontMapClass *class)
 
   gobject_class->finalize  = pango_cairo_fc_font_map_finalize;
 
-  fcfontmap_class->context_substitute = pango_cairo_fc_font_map_context_substitute;
+  fcfontmap_class->fontset_key_substitute = pango_cairo_fc_font_map_fontset_key_substitute;
   fcfontmap_class->get_resolution = pango_cairo_fc_font_map_get_resolution_fc;
 
   fcfontmap_class->context_key_get = pango_cairo_fc_font_map_context_key_get;
